Encoder

Struct Encoder 

pub struct Encoder { /* private fields */ }
Encodes video.

Implementations

Source

impl Encoder

pub fn builder() -> Setup

Creates a new builder with default options.

For more options see Setup::new.

pub fn encode( &mut self, pts: i64, image: Image<'_>, ) -> Result<(Data<'_>, Picture)>

Feeds a frame to the encoder.

Panics

Panics if there is a mismatch between the image and the encoder regarding width, height or colorspace.

pub unsafe fn encode_drh( &mut self, image: Image<'_>, idr: bool, context: *mut c_void, ) -> Result<Picture>

Feeds a frame to the encoder relying on a nalu_process callback for further processing

Safety

context must be a valid pointer to pass to the callback assigned to x264_param_t.nalu_process

pub unsafe fn encode_unchecked( &mut self, pts: i64, image: Image<'_>, ) -> Result<(Data<'_>, Picture)>

Feeds a frame to the encoder.

Unsafety

The caller must ensure that the width, height and colorspace of the image are the same as that of the encoder.

pub fn headers(&mut self) -> Result<Data<'_>>

Gets the video headers, which should be sent first.

pub fn flush(self) -> Flush

Begins flushing the encoder, to handle any delayed frames.

let mut flush = encoder.flush();

while let Some(result) = flush.next() {
    if let Ok((data, picture)) = result {
        // Handle data.
    }
}
pub fn width(&self) -> i32

The width required of any input images.

pub fn height(&self) -> i32

The height required of any input images.

pub fn encoding(&self) -> Encoding

The encoding required of any input images.